@@ -223,7 +223,7 @@ public abstract class ReactorClient {
             log.info("No interaction with host '{}' for {} ms.", getHostname(), incoming);
             this.half = false;
         }
-        if (!this.isInInit() && this.policy.isIncomingHeartbeat() && this.isIncomingHeartbeatExceeded()) {
+        if (this.policy.isIncomingHeartbeat() && this.isIncomingHeartbeatExceeded()) {
             String msg = String.format("Connection timeout for host '%s', last response arrived %s ms ago.",
                     getHostname(),
                     getHeartbeatTime());
